RecoveredBundle

Struct RecoveredBundle 

pub struct RecoveredBundle { /* private fields */ }
Version of SignetEthBundle with decoded transactions.

Implementations

Source

impl RecoveredBundle

pub const fn txs(&self) -> &[Recovered<TxEnvelope>]

Get the transactions.

pub const fn host_txs(&self) -> &[Recovered<TxEnvelope>]

Get the host transactions.

pub fn drain_txns(&mut self) -> impl Iterator<Item = Recovered<TxEnvelope>> + '_

Get an iterator draining the transactions.

pub fn drain_host_txns( &mut self, ) -> impl Iterator<Item = Recovered<TxEnvelope>> + '_

Get an iterator draining the host transactions.

pub fn tx_reqs(&self) -> impl Iterator<Item = TxRequirement> + '_

Get an iterator over the transaction requirements:

  • signer address
  • nonce
  • min_balance ((max_fee_per_gas * gas_limit) + value)
pub fn host_tx_reqs(&self) -> impl Iterator<Item = TxRequirement> + '_

Get an iterator over the host transaction requirements:

  • signer address
  • nonce
  • min_balance ((max_fee_per_gas * gas_limit) + value)
pub const fn block_number(&self) -> u64

Getter for block_number, a standard bundle prop.

pub const fn valid_timestamp_range(&self) -> RangeInclusive<u64>

Get the valid timestamp range for this bundle.

pub const fn raw_min_timestamp(&self) -> Option<u64>

Getter for min_timestamp, a standard bundle prop.

pub const fn min_timestamp(&self) -> u64

Getter for Self::raw_min_timestamp, with default of 0.

pub const fn raw_max_timestamp(&self) -> Option<u64>

Getter for max_timestamp, a standard bundle prop.

pub const fn max_timestamp(&self) -> u64

Getter for Self::raw_max_timestamp, with default of u64::MAX.

pub const fn reverting_tx_hashes(&self) -> &[TxHash]

Getter for reverting_tx_hashes, a standard bundle prop.

pub const fn replacement_uuid(&self) -> Option<&str>

Getter for replacement_uuid, a standard bundle prop.

pub const fn dropping_tx_hashes(&self) -> &[TxHash]

Getter for dropping_tx_hashes, a standard bundle prop.

pub const fn refund_percent(&self) -> Option<u8>

Getter for refund_percent, a standard bundle prop.

pub const fn refund_recipient(&self) -> Option<Address>

Getter for refund_recipient, a standard bundle prop.

pub const fn refund_tx_hashes(&self) -> &[TxHash]

Getter for refund_tx_hashes, a standard bundle prop.

pub const fn extra_fields(&self) -> &OtherFields

Getter for extra_fields, a standard bundle prop.

pub fn is_valid_at_timestamp(&self, timestamp: u64) -> bool

Checks if the bundle is valid at a given timestamp.

pub const fn is_valid_at_block_number(&self, block_number: u64) -> bool

Checks if the bundle is valid at a given block number.