pub struct SignetCallBundle {
pub bundle: EthCallBundle,
}Expand description
Bundle of transactions for signet_callBundle.
The Signet bundle contains the following:
- A standard
EthCallBundlewith the transactions to simulate. - A mapping of assets to users to amounts, which are the host fills to be checked against market orders after simulation.
This is based on the flashbots eth_callBundle bundle. See their docs.
Fields
bundle: EthCallBundleThe bundle of transactions to simulate. Same structure as a Flashbots
EthCallBundle bundle.
Implementations
Sourceimpl SignetCallBundle
impl SignetCallBundle
Sourcepub const fn block_number(&self) -> u64
pub const fn block_number(&self) -> u64
Returns the block number for this bundle.
Sourcepub const fn state_block_number(&self) -> BlockNumberOrTag
pub const fn state_block_number(&self) -> BlockNumberOrTag
Returns the state block number for this bundle.
Sourcepub const fn difficulty(&self) -> Option<U256>
pub const fn difficulty(&self) -> Option<U256>
Returns the difficulty for this bundle.
Sourcepub fn append_2718_tx(self, tx: impl Encodable2718) -> Self
pub fn append_2718_tx(self, tx: impl Encodable2718) -> Self
Adds an Encodable2718 transaction to the bundle.
Sourcepub fn append_raw_tx(self, tx: impl Into<Bytes>) -> Self
pub fn append_raw_tx(self, tx: impl Into<Bytes>) -> Self
Adds an EIP-2718 envelope to the bundle.
Sourcepub fn extend_2718_txs<I, T>(self, tx: I) -> Selfwhere
I: IntoIterator<Item = T>,
T: Encodable2718,
pub fn extend_2718_txs<I, T>(self, tx: I) -> Selfwhere
I: IntoIterator<Item = T>,
T: Encodable2718,
Adds multiple Encodable2718 transactions to the bundle.
Sourcepub fn extend_raw_txs<I, T>(self, txs: I) -> Self
pub fn extend_raw_txs<I, T>(self, txs: I) -> Self
Adds multiple calls to the block.
Sourcepub const fn with_block_number(self, block_number: u64) -> Self
pub const fn with_block_number(self, block_number: u64) -> Self
Sets the block number for the bundle.
Sourcepub fn with_state_block_number(
self,
state_block_number: impl Into<BlockNumberOrTag>,
) -> Self
pub fn with_state_block_number( self, state_block_number: impl Into<BlockNumberOrTag>, ) -> Self
Sets the state block number for the bundle.
Sourcepub const fn with_timestamp(self, timestamp: u64) -> Self
pub const fn with_timestamp(self, timestamp: u64) -> Self
Sets the timestamp for the bundle.
Sourcepub const fn with_gas_limit(self, gas_limit: u64) -> Self
pub const fn with_gas_limit(self, gas_limit: u64) -> Self
Sets the gas limit for the bundle.
Sourcepub const fn with_difficulty(self, difficulty: U256) -> Self
pub const fn with_difficulty(self, difficulty: U256) -> Self
Sets the difficulty for the bundle.
Sourcepub const fn with_base_fee(self, base_fee: u128) -> Self
pub const fn with_base_fee(self, base_fee: u128) -> Self
Sets the base fee for the bundle.
Sourcepub fn bundle_hash(&self) -> B256
pub fn bundle_hash(&self) -> B256
Calculate the bundle hash for this bundle.
The hash is calculated as
keccak256(tx_hash1 || tx_hash2 || ... || tx_hashn) where || is the
concatenation operator.
Sourcepub fn decode_and_validate_txs<Db: Database>(
&self,
) -> Result<Vec<TxEnvelope>, BundleError<Db>>
pub fn decode_and_validate_txs<Db: Database>( &self, ) -> Result<Vec<TxEnvelope>, BundleError<Db>>
Decode and validate the transactions in the bundle.