pub struct SignetEthBundle {
pub bundle: EthSendBundle,
pub host_txs: Vec<Bytes>,
}Expand description
Bundle of transactions for signet_sendBundle.
The Signet bundle contains the following:
- A standard
EthSendBundlewith the transactions to simulate. - Host transactions to be included in the host bundle.
This is based on the flashbots eth_sendBundle bundle. See their docs.
Fields
bundle: EthSendBundleThe bundle of transactions to simulate. Same structure as a Flashbots EthSendBundle bundle.
host_txs: Vec<Bytes>Host transactions to be included in the host bundle.
Implementations
Sourceimpl SignetEthBundle
impl SignetEthBundle
Sourcepub const fn new(bundle: EthSendBundle, host_txs: Vec<Bytes>) -> Self
pub const fn new(bundle: EthSendBundle, host_txs: Vec<Bytes>) -> Self
Creates a new SignetEthBundle from an existing EthSendBundle.
Sourcepub fn into_parts(self) -> (EthSendBundle, Vec<Bytes>)
pub fn into_parts(self) -> (EthSendBundle, Vec<Bytes>)
Decomposes the SignetEthBundle into its parts.
Sourcepub const fn host_txs_mut(&mut self) -> &mut Vec<Bytes>
pub const fn host_txs_mut(&mut self) -> &mut Vec<Bytes>
Get a mutable reference to the host transactions.
Sourcepub fn decode_txs(&self) -> impl Iterator<Item = Eip2718Result<TxEnvelope>> + '_
pub fn decode_txs(&self) -> impl Iterator<Item = Eip2718Result<TxEnvelope>> + '_
Return an iterator over decoded transactions in this bundle.
Sourcepub fn decode_host_txs(
&self,
) -> impl Iterator<Item = Eip2718Result<TxEnvelope>> + '_
pub fn decode_host_txs( &self, ) -> impl Iterator<Item = Eip2718Result<TxEnvelope>> + '_
Return an iterator over decoded host transactions in this bundle.
This may be empty if no host transactions were included.
Sourcepub fn recover_txs(
&self,
) -> impl Iterator<Item = Result<Recovered<TxEnvelope>, BundleRecoverError>> + '_
pub fn recover_txs( &self, ) -> impl Iterator<Item = Result<Recovered<TxEnvelope>, BundleRecoverError>> + '_
Return an iterator over recovered transactions in this bundle. This iterator may include errors.
Sourcepub fn recover_host_txs(
&self,
) -> impl Iterator<Item = Result<Recovered<TxEnvelope>, BundleRecoverError>> + '_
pub fn recover_host_txs( &self, ) -> impl Iterator<Item = Result<Recovered<TxEnvelope>, BundleRecoverError>> + '_
Return an iterator over recovered host transactions in this bundle. This iterator may include errors.
Sourcepub fn try_into_recovered(self) -> Result<RecoveredBundle, BundleRecoverError>
pub fn try_into_recovered(self) -> Result<RecoveredBundle, BundleRecoverError>
Create a RecoveredBundle from this bundle by decoding and recovering
all transactions, taking ownership of the bundle.
Sourcepub fn try_to_recovered(&self) -> Result<RecoveredBundle, BundleRecoverError>
pub fn try_to_recovered(&self) -> Result<RecoveredBundle, BundleRecoverError>
Create a RecoveredBundle from this bundle by decoding and recovering
all transactions, cloning other fields as necessary.
Sourcepub fn signers(&self) -> impl Iterator<Item = Option<(TxHash, Address)>> + '_
pub fn signers(&self) -> impl Iterator<Item = Option<(TxHash, Address)>> + '_
Return an iterator over the signers of the transactions in this bundle.
The iterator yields Option<(TxHash, Address)> for each transaction,
where None indicates that the signer could not be recovered.
Computing this may be expensive, as it requires decoding and recovering the signer for each transaction. It is recommended to memoize the results
Sourcepub fn signers_lossy(&self) -> impl Iterator<Item = (TxHash, Address)> + '_
pub fn signers_lossy(&self) -> impl Iterator<Item = (TxHash, Address)> + '_
Return an iterator over the signers of the transactions in this bundle, skipping any transactions where the signer could not be recovered.
Sourcepub const fn block_number(&self) -> u64
pub const fn block_number(&self) -> u64
Returns the block number for this bundle.
Sourcepub const fn min_timestamp(&self) -> Option<u64>
pub const fn min_timestamp(&self) -> Option<u64>
Returns the minimum timestamp for this bundle.
Sourcepub const fn max_timestamp(&self) -> Option<u64>
pub const fn max_timestamp(&self) -> Option<u64>
Returns the maximum timestamp for this bundle.
Sourcepub const fn reverting_tx_hashes(&self) -> &[B256] ⓘ
pub const fn reverting_tx_hashes(&self) -> &[B256] ⓘ
Returns the reverting tx hashes for this bundle.
Sourcepub const fn replacement_uuid(&self) -> Option<&str>
pub const fn replacement_uuid(&self) -> Option<&str>
Returns the replacement uuid for this bundle.
Sourcepub fn is_valid_at_timestamp(&self, timestamp: u64) -> bool
pub fn is_valid_at_timestamp(&self, timestamp: u64) -> bool
Checks if the bundle is valid at a given timestamp.
Sourcepub const fn is_valid_at_block_number(&self, block_number: u64) -> bool
pub const fn is_valid_at_block_number(&self, block_number: u64) -> bool
Checks if the bundle is valid at a given block number.
Sourcepub fn decode_and_validate_txs<Db: Database>(
&self,
) -> Result<Vec<TxEnvelope>, BundleError<Db>>
pub fn decode_and_validate_txs<Db: Database>( &self, ) -> Result<Vec<TxEnvelope>, BundleError<Db>>
Decode and validate the transactions in the bundle.
Sourcepub fn decode_and_validate_host_txs<Db: Database>(
&self,
) -> Result<Vec<TxEnvelope>, BundleError<Db>>
pub fn decode_and_validate_host_txs<Db: Database>( &self, ) -> Result<Vec<TxEnvelope>, BundleError<Db>>
Decode and validate the host transactions in the bundle.