pub type BundleInspector<I = NoOpInspector> = Layered<TimeLimit, I>;Expand description
The inspector type required by the Signet bundle driver.
Aliased Type
pub struct BundleInspector<I = NoOpInspector> { /* private fields */ }pub type BundleInspector<I = NoOpInspector> = Layered<TimeLimit, I>;The inspector type required by the Signet bundle driver.
pub struct BundleInspector<I = NoOpInspector> { /* private fields */ }