Crate signet_bundle

Crate signet_bundle 

Signet Bundle Library

Contains the SignetCallBundle and SignetEthBundle type, and utilities related to creating and simulating Signet bundles.

Bundles

The SignetCallBundle and SignetEthBundle types are used to simulate transaction bundles in different ways. The SignetBundleDriver type drives a SignetCallBundle to completion and generates a SignetCallBundleResponse. This is used primarily by the RPC server to serve signet_callBundle requests. The response includes the standard flashbots-style response information, as well as a description of the fills necessary to make the bundle valid on Signet.

The SignetEthBundle type is used to simulate transaction bundles while building blocks. It is used primarily by builders and relays. The SignetEthBundleDriver drives a SignetEthBundle to completion and enforces bundle rules. When used in a block builder, it will ensure that the bundle is valid and that the fills are valid at the time of block construction.

Using SignetEthBundle safely

The SignetEthBundle type contains actions that must be performed on both chains. As such, its simulation must be performed on both chains. The primary transaction simulation via SignetEthBundleDriver is performed locally using trevm.

Structs

BundleRecoverError
Decoding error specifying the an error encountered while decoding transactions in a Signet bundle.
RecoveredBundle
Version of SignetEthBundle with decoded transactions.
SignetBundleDriver
A call bundle driver for the Signet EVM.
SignetCallBundle
Bundle of transactions for signet_callBundle.
SignetCallBundleResponse
Response for signet_callBundle.
SignetEthBundle
Bundle of transactions for signet_sendBundle.
SignetEthBundleDriver
Driver for applying a Signet Ethereum bundle to an EVM.
TxRequirement
Transaction requirement info for a single transaction.

Enums

RecoverError
Errors that can occur while recovering signatures from transactions in bundles.
SignetEthBundleError
Errors while running a SignetEthBundle on the EVM.

Traits

SignetBundleApi
Signet namespace RPC interface.

Type Aliases

BundleInspector
The inspector type required by the Signet bundle driver.
SignetEthBundleInsp
Inspector used in the impl of BundleDriver for SignetEthBundleDriver.