pub struct SignetCallBundleResponse {
pub orders: AggregateOrders,
pub fills: AggregateFills,
/* private fields */
}Expand description
Response for signet_callBundle.
The response contains the following:
- The inner
EthCallBundleResponseresponse. - Aggregate orders produced by the bundle.
- Fills produced by the bundle.
The aggregate orders contains both the net outputs the filler can expect to receive from this bundle and the net inputs the filler must provide to ensure this bundle is valid.
Fields
orders: AggregateOrdersAggregate orders produced by the bundle.
This mapping will contain all outputs and required inputs, collapsed into a single entry per asset. For the bundle to be valid, there must be fills for all the inputs in this mapping. Which is to say, this type indicates the following:
- The net outputs the filler can expect to receive from this bundle.
- The net inputs the filler must provide to ensure this bundle is valid.
fills: AggregateFillsFills produced by the bundle. This will contain the net fills produced by the transaction. These can be deducted from the net inputs required by the orders to ensure the bundle is valid.
Implementations
Sourceimpl SignetCallBundleResponse
impl SignetCallBundleResponse
Sourcepub fn accumulate_tx<Db: Database>(
&mut self,
tx: &TxEnvelope,
coinbase_diff: U256,
base_fee: u64,
execution_result: ExecutionResult,
) -> Result<(), BundleError<Db>>
pub fn accumulate_tx<Db: Database>( &mut self, tx: &TxEnvelope, coinbase_diff: U256, base_fee: u64, execution_result: ExecutionResult, ) -> Result<(), BundleError<Db>>
Accumulate the result of transaction execution into the response.