pub struct SignetEthBundle {
pub bundle: EthSendBundle,
pub host_fills: Option<SignedFill>,
}Expand description
Bundle of transactions for signet_sendBundle.
The Signet bundle contains the following:
- A standard
EthSendBundlewith the transactions to simulate. - A signed permit2 fill to be applied on the Host chain with the bundle.
This is based on the flashbots eth_sendBundle bundle. See their docs.
Fields
bundle: EthSendBundleThe bundle of transactions to simulate. Same structure as a Flashbots EthSendBundle bundle.
host_fills: Option<SignedFill>Host fills to be applied with the bundle, represented as a signed permit2 fill.
Implementations
Sourceimpl SignetEthBundle
impl SignetEthBundle
Sourcepub const fn block_number(&self) -> u64
pub const fn block_number(&self) -> u64
Returns the block number for this bundle.
Sourcepub const fn min_timestamp(&self) -> Option<u64>
pub const fn min_timestamp(&self) -> Option<u64>
Returns the minimum timestamp for this bundle.
Sourcepub const fn max_timestamp(&self) -> Option<u64>
pub const fn max_timestamp(&self) -> Option<u64>
Returns the maximum timestamp for this bundle.
Sourcepub fn reverting_tx_hashes(&self) -> &[B256] ⓘ
pub fn reverting_tx_hashes(&self) -> &[B256] ⓘ
Returns the reverting tx hashes for this bundle.
Sourcepub fn replacement_uuid(&self) -> Option<&str>
pub fn replacement_uuid(&self) -> Option<&str>
Returns the replacement uuid for this bundle.
Sourcepub fn decode_and_validate_txs<Db: Database>(
&self,
) -> Result<Vec<TxEnvelope>, BundleError<Db>>
pub fn decode_and_validate_txs<Db: Database>( &self, ) -> Result<Vec<TxEnvelope>, BundleError<Db>>
Decode and validate the transactions in the bundle.
Sourcepub fn validate_fills_offchain(
&self,
timestamp: u64,
) -> Result<(), SignedPermitError>
pub fn validate_fills_offchain( &self, timestamp: u64, ) -> Result<(), SignedPermitError>
Check that this can be syntactically used as a fill.
Sourcepub async fn alloy_validate_fills_onchain<Db, P, N>(
&self,
orders: HostOrdersInstance<P, N>,
) -> Result<(), SignetEthBundleError<Db>>
pub async fn alloy_validate_fills_onchain<Db, P, N>( &self, orders: HostOrdersInstance<P, N>, ) -> Result<(), SignetEthBundleError<Db>>
Check that this fill is valid on-chain as of the current block. This checks that the tokens can actually be transferred.