pub trait SignetBundleApi<N: Network = Ethereum>: Send + Sync {
// Required method
fn call_bundle(
&self,
bundle: SignetCallBundle,
) -> impl Future<Output = TransportResult<SignetCallBundleResponse>> + Send;
}Expand description
Signet namespace RPC interface.
Required Methods
Sourcefn call_bundle(
&self,
bundle: SignetCallBundle,
) -> impl Future<Output = TransportResult<SignetCallBundleResponse>> + Send
fn call_bundle( &self, bundle: SignetCallBundle, ) -> impl Future<Output = TransportResult<SignetCallBundleResponse>> + Send
Simulates a bundle of transactions against a specific block and returns the execution results.
This is similar to the Flashbots eth_callBundle endpoint, but includes
Signet-specific fields like aggregate orders and fills in the response.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.